<?php
/**
 * 
 * @author Philippe Melot
 * @copyright Nadeo
 */

require_once(APP_INCLUDE_PATH.'utils.php');
require_once(APP_MVC_FRAMEWORK_FILTERS_PATH.'UserAgentCheckFilter.class.php');
require_once(APP_MVC_FRAMEWORK_FILTERS_PATH.'DebugFilter.class.php');
require_once(APP_MVC_FILTERS_PATH.'DaoAutoloadFilter.class.php');


class homeController extends ActionController
{
	function __construct($controllerName)
	{
		parent::__construct($controllerName);

		$this->addFilter(new UserAgentCheckFilter);
		$this->addFilter(new DebugFilter);
		$this->addFilter(new DaoAutoloadFilter);
	}

	function index($playerlogin = '')
	{
		if(file_exists(APP_PATH.'/controllers/installController.class.php'))
		{
			if(file_exists(APP_PATH.'logs/setup'))
			{
				$action = file_get_contents(APP_PATH.'logs/setup');
				$this->request->redirectManialinkArgList('install',$action);
			}
			else
			{
				$this->request->redirectManialinkArgList('install','index');
			}
		}
		if(($this->session->get('user') && $this->session->get('transaction')) || $playerlogin)
		{
			$this->request->redirectManialink('user','index');
		}
	}

	function end_install()
	{
		$installControllerFilePath = APP_PATH.'controllers/installController.class.php';
		if(file_exists($installControllerFilePath) && is_writable($installControllerFilePath))
		{
			@unlink($installControllerFilePath);
			if(file_exists(APP_PATH.'logs/setup') && is_writable(APP_PATH.'logs/setup'))
			{
				@unlink(APP_PATH.'logs/setup');
			}
			$this->chainActionAndView(null,'index');
		}
		else
		{
			$this->response->dialogTitle = 'Finish Install';
			$this->response->dialogButtonLabel = 'Continue';
			$this->response->dialogButtonManialink = $this->request->createLinkArgList(null,'index');
			$this->response->dialogMessage = "Server can't remove $installControllerFilePath please delete it before clicking on continue";
		}
	}

	function connection($playerlogin)
	{
		$this->request->redirectManialink('user','index');
	}

	function download($fid, $dl = '')
	{
		$vips = explode(',',VIP_USERS);
		try
		{
			$file = FileDao::getFileFromId($fid);
			$user = UserDao::getUserFromId($file->getUserId());
			if(!in_array($user->getLogin(), $vips) && $user->getExpirationTime() < time())
			{
				throw new FrameworkUserException('Cannot access to the file. User account expired');
			}
		}
		catch(Exception $e)
		{
			if(APP_DEBUG_LEVEL)
			{
				throw new FrameworkImportedException($e);
			}
			else
			{
				$this->response->resetViews();
				$this->response->dialogTitle = __('error');
				$this->response->dialogMessage = 'An error occured while retrieving your file';
				$this->response->dialogButtonLabel = __('continue');
				$this->response->dialogButtonManialink = 'Manialink:Home';
				$this->response->registerDialog('dialogs','generic_dialog');
				return;
			}
		}

		$filename = $file->getName();
		$fileUrl = APP_URL.'download/'.$user->getLogin().'/'.$file->getName();
		if($dl)
		{
			Maniacode::load();
			{
				$file = new ShowMessage('The file will be download in the ManiaHost folder in your Trackmania Skins folder');
				$file->save();
				$file = new InstallSkin($filename,$fileUrl);
				$file->setFile('Skins/ManiaHost/'.$filename);
				$file->save();
			}
			Maniacode::render();
		}
		else
		{
			$this->request->set('dl',time());
			$manialink = $this->request->createAbsoluteLinkArgList(APP_MANIALINK,URL_PARAM_NAME_ACTION,'fid','dl');
			$this->request->delete('dl');
			$this->response->dialogTitle = __('file_download_title');
			$this->response->dialogMessage = __('file_download_message', __('web_browser'), __('manialink_browser'));
			$this->response->dialogButtonLabel = __('web_browser');
			$this->response->dialogButtonManialink = $fileUrl;
			$this->response->dialogButton2Label = __('manialink_browser');
			$this->response->dialogButton2Manialink = $manialink;
		}

	}
}
?>
