<?php
/**
 * 
 * @author Philippe Melot
 * @copyright Nadeo
 */

require_once(APP_MVC_FRAMEWORK_FILTERS_PATH.'RegisterRequestParametersFilter.class.php');
require_once(APP_MVC_FILTERS_PATH.'DaoAutoloadFilter.class.php');
require_once(APP_MVC_FRAMEWORK_FILTERS_PATH.'UserAgentCheckFilter.class.php');

class installController extends ActionController
{
	function __construct($controllerName = 'installController')
	{
		parent::__construct($controllerName);
		$this->addFilter(new UserAgentCheckFilter);
		$this->addFilter(new RegisterRequestParametersFilter);
		$this->addFilter(new DaoAutoloadFilter);
	}

	function index()
	{
		$folder = array();
		//Check rights in different folders
		$error = '';
		if(is_writable(APP_PATH.'config/config.php'))
		$folder['config/config.php'] = true;
		else
		{
			$error .= "Can't write in config/config.php file\n";
			$folder['config/config.php'] = false;
		}
		if(is_writable(APP_PATH.'download/'))
		$folder['download/'] = true;
		else
		{
			$error .= "Can't write in download folder\n";
			$folder['download/'] = false;
		}

		if(is_writable(APP_PATH.'logs/'))
		$folder['logs/'] = true;
		else
		{
			$error .= "Can't write in logs folder\n";
			$folder['logs/'] = false;
		}

		if(!$error)
		{
			$manialinkLabel = 'Continue';
			$manialink = $this->request->createLink(null,'database');
		}
		else
		{
			$manialinkLabel = 'Retry';
			$manialink = $this->request->createLink(null,null);
		}

		$this->response->folder = $folder;
		$this->response->error = $error;
		$this->response->manialinkLabel = $manialinkLabel;
		$this->response->manialink = $manialink;
	}

	function database()
	{
		file_put_contents(APP_PATH.'logs/setup','database');
	}

	function registerDb($dbUsername = '', $dbPassword = '', $dbName = '', $dbHost = '', $dbPrefix = '')
	{
		if($dbUsername && $dbName && $dbHost)
		{
			$this->request->delete('dbUsername');
			$this->request->delete('dbPassword');
			$this->request->delete('dbName');
			$this->request->delete('dbHost');
			$this->request->delete('dbPrefix');
			$dbInstance = null;
			try
			{
				$dbInstance = DatabaseFactory::getConnection($dbHost,$dbUsername,$dbPassword,$dbName);
			}
			catch(Exception $e)
			{
				$this->response->Error = "Can't connect to the database";
				$this->chainActionAndView(null,'database');
				return;
			}

			//Set database Defines in config file
			$data = file_get_contents(APP_PATH.'config/config.php');

			if(!strstr($data, 'APP_DATABASE_HOST'))
			{
				$replace = "\ndefine('APP_DATABASE_HOST',		'$dbHost');\n"
				."define('APP_DATABASE_USER',		'$dbUsername');\n"
				."define('APP_DATABASE_PASSWORD',	'$dbPassword');\n"
				."define('APP_DATABASE_NAME', 	'$dbName');\n"
				."define('APP_DATABASE_PREFIX', 	'$dbPrefix');\n"
				."require_once APP_PATH.'dao/ConfigDao.class.php';\n"
				."ConfigDao::getConfig();\n?>";

				$data = str_replace('?>',$replace,$data);

				file_put_contents(APP_PATH.'config/config.php',$data);
			}
			$queries = array();

			$queries[] = "CREATE  TABLE IF NOT EXISTS `{$dbPrefix}User` (\n"
			."`id` INT UNSIGNED NOT NULL AUTO_INCREMENT ,\n"
			."`login` VARCHAR(25) NOT NULL ,\n"
			."`isAdmin` TINYINT(1)  NOT NULL DEFAULT false ,\n"
			."`occupiedSpace` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."`trafficConsumption` INT UNSIGNED NULL DEFAULT 0 ,\n"
			."`subscriptionTime` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."`expirationTime` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."`transactionId` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."UNIQUE INDEX `login_UNIQUE` (`login` ASC) ,\n"
			."PRIMARY KEY (`id`) )\n"
			."ENGINE = MyISAM\n"
			."DEFAULT CHARACTER SET = utf8\n"
			."COLLATE = utf8_general_ci;";

			$queries[] = "CREATE  TABLE IF NOT EXISTS `{$dbPrefix}File` (\n"
			."`id` INT NOT NULL AUTO_INCREMENT ,\n"
			."`name` VARCHAR(45) NOT NULL ,\n"
			."`userId` INT NOT NULL ,\n"
			."`size` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."`uploadTimestamp` INT NOT NULL ,\n"
			."`downloadNb` INT NOT NULL DEFAULT 0 ,\n"
			."PRIMARY KEY (`id`) ,\n"
			."INDEX `userId` (`userId` ASC) ,\n"
			."UNIQUE INDEX `filename_author` (`name` ASC, `userId` ASC) )\n"
			."ENGINE = MyISAM\n"
			."DEFAULT CHARACTER SET = utf8\n"
			."COLLATE = utf8_general_ci;";

			$queries[] = "CREATE  TABLE IF NOT EXISTS `{$dbPrefix}Subscription` (\n"
			."`id` INT UNSIGNED NOT NULL AUTO_INCREMENT ,\n"
			."`name` VARCHAR(45) NOT NULL ,\n"
			."`cost` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."`trafficLimit` INT NOT NULL DEFAULT 0 ,\n"
			."`period` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."PRIMARY KEY (`id`) )\n"
			."ENGINE = MyISAM\n"
			."DEFAULT CHARACTER SET = utf8\n"
			."COLLATE = utf8_general_ci;";


			$queries[] = "CREATE  TABLE IF NOT EXISTS `{$dbPrefix}Download` (\n"
			."`id` INT UNSIGNED NOT NULL AUTO_INCREMENT ,\n"
			."`fileId` INT UNSIGNED NOT NULL ,\n"
			."`downloadTime` INT UNSIGNED NOT NULL ,\n"
			."PRIMARY KEY (`id`) ,\n"
			."INDEX `IX_fileId` (`fileId` ASC) )\n"
			."ENGINE = MyISAM\n"
			."DEFAULT CHARACTER SET = utf8\n"
			."COLLATE = utf8_general_ci;";


			$queries[] = "CREATE  TABLE IF NOT EXISTS `{$dbPrefix}Transaction` (\n"
			."`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,\n"
			."`login` VARCHAR(25) NOT NULL ,\n"
			."`idSubscription` INT UNSIGNED NULL DEFAULT NULL ,\n"
			."`amount` INT UNSIGNED NOT NULL ,\n"
			."`status` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."`period` INT UNSIGNED NOT NULL DEFAULT 0 ,\n"
			."`creationTime` INT UNSIGNED NOT NULL ,\n"
			."`paymentCount` INT UNSIGNED NOT NULL ,\n"
			."PRIMARY KEY (`id`) ,\n"
			."INDEX `login` (`login` ASC) )\n"
			."ENGINE = MyISAM\n"
			."DEFAULT CHARACTER SET = utf8\n"
			."COLLATE = utf8_general_ci;";

			$queries[] = "CREATE  TABLE IF NOT EXISTS `{$dbPrefix}Config` (\n"
			."`key` VARCHAR(45) NOT NULL ,\n"
			."`value` VARCHAR(2048) NOT NULL ,\n"
			."PRIMARY KEY (`key`) )\n"
			."ENGINE = MyISAM\n"
			."DEFAULT CHARACTER SET = utf8\n"
			."COLLATE = utf8_general_ci;";

			$playerLogin = $this->session->getStrict('login');
			$playerLogin = $dbInstance->quote($playerLogin);
			$queries[] = "INSERT IGNORE INTO `{$dbPrefix}User` (`login`, `isAdmin`) VALUES\n"
			."($playerLogin, TRUE);";

			try
			{
				foreach($queries as $query)
				{
					$dbInstance->execute($query);
				}
			}
			catch(Exception $e)
			{
				$this->response->Error = $e->getMessage();
				$this->chainActionAndView(null,'database');
				return;
			}
			$this->session->set('userid',$dbInstance->insertID());
			$this->request->redirectManialink(null,'param');
		}
		else
		{
			$this->response->Error = 'Please enter at least database username, database name and database host';
			$this->request->chainActionAndView(null,'database');
		}
	}

	function param()
	{
		file_put_contents(APP_PATH.'logs/setup','param');
	}

	function registerSettings($mlName, $mlUrl, $mlTitle, $userMax, $userSpace, $cost)
	{
		if(!is_numeric($userMax))
		{
			$this->response->Error = 'The max number of this service must be an integer';
			$this->chainActionAndView(null,'param');
			return;
		}

		if(!is_numeric($userSpace))
		{
			$this->response->Error = 'The allowed size per user must be a number';
			$this->chainActionAndView(null,'param');
			return;
		}

		$this->request->delete('mlName');
		$this->request->delete('mlUrl');
		$this->request->delete('mlTitle');
		$this->request->delete('userMax');
		$this->request->delete('userSpace');

		$config = array();
		$config['APP_URL'] = $mlUrl;
		$config['APP_MANIALINK'] = $mlName;
		$config['APP_TITLE'] = $mlTitle;
		$config['APP_DEBUG_LEVEL'] = 0;
		$config['MAX_USER'] = $userMax;
		$config['SPACE_PER_USER'] = $userSpace * 1024 * 1024;
		$config['DEFAULT_PERIOD'] = 2592000;
		$config['REGISTRATION_STATUS'] = 0;
		$config['VIP_USERS'] = $this->session->getStrict('login');
		$config['LAST_CLEAN_TIME'] = time();
		$config['STATISTICS_GRAPHIC_STATUS'] = 1;
		$config['MANIAHOME_MANIALINK'] = $mlName;
		//ManiaHome Parameters

		try
		{
			ConfigDao::setConfig($config);
			ConfigDao::getConfig();
		}
		catch(Exception $e)
		{
			$this->response->Error = $e->getMessage();
			debuglog($e);
			$this->chainActionAndView(null,'param');
			return;
		}

		$sid = 0;
		try
		{
			$subscription = SubscriptionDao::getSubscription(1);
			if(!$subscription)
			{
				$sid = SubscriptionDao::setSubscription('default',$cost, 0, 2592000);
			}
			else
			{
				$sid = $subscription->getId();
			}
		}
		catch (Exception $e)
		{
			$this->response->error = $e->getMessage();
			$this->chainActionAndView(null,'param');
			return;
		}

		if($sid !== 0)
		{
			try
			{
				$user = UserDao::getUserFromLogin($this->session->getStrict('login'));
				if(!$user->getTransactionId())
				{
					$tid = TransactionDao::setTransaction($this->session->getStrict('login'),$sid,0,TransactionModel::ACTIVE,0,0);
					UserDao::updateTransaction($user->getId(),$tid);
				}
			}
			catch(Exception $e)
			{
				foobar($e);
				$this->response->error = $e->getMessage();
				$this->chainActionAndView(null,'param');
				return;
			}
		}
		else
		{
			$this->response->error = 'Failed to register subscription';
			$this->chainActionAndView(null,'param');
			return;
		}

		if(!$this->response->error)
		{
			$this->request->redirectManialink(null,'maniahome');
		}
	}

	function maniahome()
	{
		file_put_contents(APP_PATH.'logs/setup','maniahome');
	}

	function registerManiaHome($username = '', $title = '', $name = '')
	{
		$password = file_get_contents('php://input');
		$config['MANIAHOME_USERNAME'] = $username;
		$config['MANIAHOME_PASSWORD'] = $password;
		$config['MANIAHOME_NAME'] = $name;
		$config['MANIAHOME_STATUS'] = (($username && $password) ? 1 : 0);
		$config['MANIAHOME_PICTURE'] = APP_URL.'images/maniahost_bookmark.dds';

		try
		{
			ConfigDao::setConfig($config);
		}
		catch(Exception $e)
		{
			$this->response->Error = $e->getMessage();
			debuglog($e);
			$this->chainActionAndView(null,'maniahome');
			return;
		}

		$this->request->redirectManialink(null,'finish');
	}

	function finish($cost = 0,$name = '')
	{
		file_put_contents(APP_PATH.'logs/setup','finish');
		$this->session->delete('userid');
		$this->response->dialogTitle = 'Finish Install';
		$this->response->dialogButtonLabel = 'Continue';
		$this->response->dialogButtonManialink = $this->request->createLinkArgList('home','end_install');
		$this->response->dialogMessage = "Setup is finish, please register the following manialinks in your playerpage:\n"
		.'$i'.APP_MANIALINK.'$z as a Manialink'."\n".' and $i'.APP_MANIALINK.':subscription$z as a maniacode of '.$cost.' coppers'."\n"
		.'set '.ceil($cost * 0.05).' to Nadeo and '.floor($cost * 0.95).' to yourself.'."\n"
		."Set the url for this two manialink with the url bellow.";
	}
}
?>
