<?php
/**
 * 
 * @author Philippe Melot
 * @copyright Nadeo
 */

require_once(APP_INCLUDE_PATH.'utils.php');
require_once(APP_MVC_FRAMEWORK_FILTERS_PATH.'UserAgentCheckFilter.class.php');
require_once(APP_MVC_FRAMEWORK_FILTERS_PATH.'RegisterRequestParametersFilter.class.php');
require_once(APP_MVC_FRAMEWORK_FILTERS_PATH.'DebugFilter.class.php');
require_once(APP_MVC_FILTERS_PATH.'DaoAutoloadFilter.class.php');
require_once(APP_MVC_FILTERS_PATH.'AuthenticationFilter.class.php');
require_once(APP_MVC_FILTERS_PATH.'VipUserFilter.class.php');
require_once(APP_PATH.'maniahomeclient/config/config.php');

class registerController extends ActionController
{
	function __construct($controllerName)
	{
		parent::__construct($controllerName);

		$this->data = DataEngine::getInstance();

		$this->addFilter(new UserAgentCheckFilter);
		$this->addFilter(new RegisterRequestParametersFilter);
		$this->addFilter(new DebugFilter);
		$this->addFilter(new DaoAutoloadFilter);
		//		$this->addFilter(new AuthenticationFilter);
		$this->addFilter(new VipUserFilter);
	}

	function index()
	{
		if(REGISTRATION_STATUS == 0 || (!$this->response->isVip && REGISTRATION_STATUS == 1))
			throw new FrameworkUserException(__('registration_close'));
		try
		{
			$subscriptions = SubscriptionDao::getSubscriptions(0,2);
			$usersCount = UserDao::getUsersCount();
		}
		catch (Exception $e)
		{
			if(APP_DEBUG_LEVEL)
			throw new FrameworkImportedException($e);
			else
			$this->request->redirectManialink('home','index');
		}

		if($usersCount >= MAX_USER)
		throw new FrameworkUserException(__('registration_maximum_reached'));

		if(!count($subscriptions))
		{
			$this->request->redirectManialink('home','index');
		}

		if($this->response->isVip)
		$this->response->cost = 0;
		else
		{
			$subscription = array_pop($subscriptions);
			$this->response->cost = $subscription->getCost();
		}

		$this->response->dialogTitle = __('registration_form_title');
		$this->response->dialogButtonLabel = __('yes');
		$this->response->dialogButtonManialink = $this->request->createLink(null,'register');
		$this->response->dialogButton2Label = __('no');
		$this->response->dialogButton2Manialink = $this->request->createLink('home','index');
	}

	function register()
	{
		try
		{
			$subscription = SubscriptionDao::getSubscriptions(0,1);
		}
		catch(Exception $e)
		{
			if(APP_DEBUG_LEVEL)
			throw new FrameworkImportedException($e);
			else
			$this->request->redirectManialink('home','index');
		}

		$this->request->set('idSubscription', $subscription[0]->getId());
		$this->request->set('periodCount', 'monthcount');
		$this->request->set(URL_PARAM_NAME_ACTION, 'credit_account');

		$this->response->dialogTitle = __('registration_form_title');
		$this->response->dialogButtonLabel = __('register_button');
		if($this->response->isVip)
		{
			$this->response->dialogButtonManialink = $this->request->createAbsoluteLinkArgList(APP_MANIALINK,URL_PARAM_NAME_CONTROLLER,URL_PARAM_NAME_ACTION,'idSubscription','periodCount');
		}
		else
		{
			$this->response->dialogButtonManialink = $this->request->createAbsoluteLinkArgList(APP_MANIALINK.':subscription',URL_PARAM_NAME_CONTROLLER,URL_PARAM_NAME_ACTION,'idSubscription','periodCount');
		}
		$this->response->dialogButton2Label = __('cancel');
		$this->response->dialogButton2Manialink = $this->request->createLinkArgList(null,'index');
		$this->response->dialogMessage = __('registration_dialog_question');
		$this->response->dialogEntryName = 'monthcount';
		$this->response->dialogEntryDefault = 1;
		$this->request->delete('periodCount');
		$this->request->delete('idSubscription');

		$this->response->resetViews();
		$this->response->registerDialog('dialogs','generic_entry_dialog');
		return;
	}

	function credit_account($idSubscription, $periodCount = 1)
	{
		$login = $this->session->getStrict('login');
		try
		{
			$user = UserDao::getUserFromLogin($login);
		}
		catch (Exception $e)
		{
			if(APP_DEBUG_LEVEL)
			throw new FrameworkImportedException($e);
			else
			$this->request->redirectManialink(null,'index');
		}

		if($periodCount >= 1)
		{
			try
			{
				$subscription = SubscriptionDao::getSubscription($idSubscription);
				if($this->response->isVip)
				$cost = 0;
				else
				$cost = ceil($subscription->getCost() * 0.95);
				$transactionId = TransactionDao::setTransaction($login,$idSubscription, $cost, TransactionModel::ACTIVE, DEFAULT_PERIOD, 1);

				if($user == null)
				{
					$userId = UserDao::setUser($login,$transactionId);
				}
				else
				{
					$userId = $user->getId();
				}

				UserDao::updateTransaction($userId,$transactionId);
			}
			catch (Exception $e)
			{
				if(APP_DEBUG_LEVEL)
				throw new FrameworkImportedException($e);
				else
				$this->request->redirectManialink(null,'index');
			}
			if($this->response->isVip)
			$periodCount = 1;
				
			$this->request->set('periodCount', $periodCount - 1);
			if($periodCount == 1)
			{
				$this->request->redirectManialinkAbsoluteArgList(APP_MANIALINK, URL_PARAM_NAME_CONTROLLER, URL_PARAM_NAME_ACTION, 'periodCount', 'idSubscription');
			}
			else
			{
				$this->request->redirectManialinkAbsoluteArgList(APP_MANIALINK.':subscription', URL_PARAM_NAME_CONTROLLER, URL_PARAM_NAME_ACTION, 'periodCount', 'idSubscription');
			}
		}
		else
		{
			$this->request->set('periodCount', 'monthcount');
			$this->response->dialogTitle = __('registration_form_title');
			$this->response->dialogButtonLabel = __('continue');
			$this->response->dialogButtonManialink = $this->request->createLink('user','index');
				
			if($this->response->isVip)
			$this->response->dialogMessage = __('registration_finish_vip');
			else
			$this->response->dialogMessage = __('registration_finish_normal',__date($user->getExpirationTime()));
				
			$this->request->delete('periodCount');

			$this->response->resetViews();
			$this->response->registerDialog('dialogs','generic_dialog');
			if(MANIAHOME_STATUS)
			{
				try
				{
					$mhc = new ManiaHomeClient();
					$mhc->sendNotificationToPlayer(
					__('maniahome_register_message',APP_TITLE),
					$login,
					APP_MANIALINK,
					ManiaHomeClient::NONE);
				}
				catch (Exception $e)
				{

				}
			}
			return;
		}
	}
}
?>