<?php
/**
 * @author Philippe Melot
 * @copyright Nadeo
 */

require_once(APP_PATH.'maniahomeclient/config/config.php');

class userController extends AbstractManiaHostController
{
	function index()
	{
		$this->request->registerReferer();
		$manialink = $this->request->createLink(null,'upload');
		try
		{
			$subscription = SubscriptionDao::getSubscription($this->data->transaction->getIdSubscription());
		}
		catch(Exception $e)
		{
			$manialink = '';
		}

		if(SPACE_PER_USER == $this->data->user->getOccupiedSpace())
		$manialink = '';

		try
		{
			$filesCount = FileDao::getFileCountFromUser($this->data->user->getId());
		}
		catch(Exception $e)
		{
			$filesCount = FILES_PER_PAGE;
		}

		$multipage = new MultipageList(FILES_PER_PAGE);
		$multipage->setSize($filesCount);
		list($offset, $length) = $multipage->getLimit();

		try
		{
			$files = FileDao::getFiles($this->data->user->getId(), $offset, $length);
		}
		catch (Exception $e)
		{
			$files = array();
		}

		$this->response->maxSpaceString = octetToString(SPACE_PER_USER);
		$this->response->maxSpace = SPACE_PER_USER;
		$this->response->usedSpaceString = octetToString($this->data->user->getOccupiedSpace());
		$this->response->usedSpace = $this->data->user->getOccupiedSpace();

		$this->response->maxTrafficString = octetToString($subscription->getTrafficLimit());
		$this->response->maxTraffic = $subscription->getTrafficLimit();
		$this->response->usedTrafficString = octetToString($this->data->user->getTrafficConsumption());
		$this->response->usedTraffic = $this->data->user->getTrafficConsumption();

		$this->response->files = $files;
		$this->response->username = $this->data->user->getLogin();
		$this->response->multipage = $multipage;
	}

	function upload($filename = '')
	{
		$maxSize = return_bytes(ini_get('post_max_size'));
		$fileSizeMax = SPACE_PER_USER - $this->data->user->getOccupiedSpace();
		if($fileSizeMax > $maxSize)
			$fileSizeMax = $maxSize;
		
		if(!$filename)
		{
			$dialogTitle = __('upload_dialog_title');
			$dialogMessage = __('upload_dialog_choose_file');

			$cancelManialink = $this->request->createLink(null, 'index');
			$this->request->set('confirm', rand());
			$continueManialink = $this->request->createLink(null, null);
			$this->request->delete('confirm');
			$this->response->maxSizeInfo = __('max_file_size',octetToString($fileSizeMax));
			$this->response->dialogTitle = $dialogTitle;
			$this->response->dialogMessage = $dialogMessage;
			$this->response->dialogButtonLabel = __('upload');
			$this->response->dialogButtonManialink = $continueManialink;
			$this->response->dialogButton2Label = __('cancel');
			$this->response->dialogButton2Manialink = $cancelManialink;
			$this->response->registerDialog('dialogs','upload_dialog');
			$this->chainActionAndView('user','index');
		}
		else
		{
			if(preg_match('/(\\.php.?)\\z/i', $filename))
			{
				$this->response->dialogTitle = __('upload_error');
				$this->response->dialogMessage = __('upload_invalid_fileformat');
				$this->response->dialogButtonLabel = __('continue');
				$this->response->dialogButtonManialink = $this->request->createLinkArgList(null,'index');
				$this->response->registerDialog('dialogs','generic_dialog');
				$this->chainActionAndView('user','index');
				return;
			}

			if (!preg_match('#^[a-z0-9-_. %\'"@&~<>;!|()=:\\*\\[\\]\#\\+\\?\\/\\\ \\{\\}$]+$#ui', $filename))
			{
				$this->response->dialogTitle = __('upload_error');
				$this->response->dialogMessage = __('upload_invalid_char');
				$this->response->dialogButtonLabel = __('continue');
				$this->response->dialogButtonManialink = $this->request->createLinkArgList(null,'index');
				$this->response->registerDialog('dialogs','generic_dialog');
				$this->chainActionAndView('user','index');
				return;
			}

			$folder_user = APP_DOWNLOAD_PATH.$this->data->user->getLogin().'/';

			if(!file_exists($folder_user))
			mkdir($folder_user,0770);

			$filesize = 0;
			$filepath = APP_DOWNLOAD_PATH.$this->data->user->getLogin().'/'.$filename;
			if(file_exists($filepath))
			$filesize = filesize($filepath);

			$uploadHandler = new ManialinkUploadHandler($folder_user,$fileSizeMax);
			try
			{
				$uploadHandler->uploadFile($filename);
			}
			catch(Exception $e)
			{
				if(file_exists($filepath.'/'.$filename))
				$uploadHandler->deleteUploadedFile();
				if(APP_DEBUG_LEVEL)
				throw new FrameworkImportedException($e);
				else
				throw new FrameworkUserException(__('upload_error'));
				$this->chainActionAndView(null,'index');
				return;
			}

			$newOccupiedSize = $uploadHandler->getUploadedFilesize() - $filesize;
			try
			{
				FileDao::setFile($filename,$this->data->user->getId(),$uploadHandler->getUploadedFilesize());
				UserDao::updateUserSpace($this->data->user->getId(),abs($newOccupiedSize),($newOccupiedSize < 0 ? 'remove' : 'add'));
			}
			catch(Exception $e)
			{
				FileDao::delFileFromName($filename,$this->data->user->getId());
				UserDao::updateUserSpace($this->data->user->getId(),abs($newOccupiedSize),($newOccupiedSize < 0 ? 'add' : 'remove'));
				$uploadHandler->deleteUploadedFile();
			}
			$this->session->delete('user');
			$this->request->redirectManialinkArgList('user','index');
		}
	}

	function share($fid, $confirm = '')
	{
		try
		{
			$file = FileDao::getFileFromId($fid);
		}
		catch (Exception $e)
		{
			if(APP_DEBUG_LEVEL)
			throw new FrameworkImportedException($e);
		}
		
		if(!$confirm)
		{
			$dialogTitle = __('share_file_dialog_title');
			$dialogMessage = __('share_file_dialog_message',$file->getName());

			$cancelManialink = $this->request->createLink(null, 'index');
			$this->request->set('confirm', rand());
			$continueManialink = $this->request->createLink(null, null);
			$this->request->delete('confirm');

			$this->response->dialogTitle = $dialogTitle;
			$this->response->dialogMessage = $dialogMessage;
			$this->response->dialogButtonLabel = __('continue');
			$this->response->dialogButtonManialink = $continueManialink;
			$this->response->dialogButton2Label = __('cancel');
			$this->response->dialogButton2Manialink = $cancelManialink;
			$this->response->registerDialog('dialogs','generic_two_buttons_dialog');
			$this->chainActionAndView('user','index');
		}
		elseif($file->getUserId() == $this->data->user->getId())
		{
			if(MANIAHOME_STATUS)
			{
				$this->request->set(URL_PARAM_NAME_ACTION, 'download');
				$manialink = $this->request->createAbsoluteLinkArgList(APP_MANIALINK,URL_PARAM_NAME_ACTION,'fid');
				$this->request->restore(URL_PARAM_NAME_ACTION);
				$mhc = new ManiaHomeClient();
				$mhc->sendNotificationToPlayer(
				__('maniahome_share', $file->getName(), APP_TITLE),
				$this->data->user->getLogin(),
				$manialink,
				ManiaHomeClient::NONE);
			}
			$this->request->redirectManialink(null,'index');
		}
	}

	function delFile($fid, $confirm = '')
	{
		try
		{
			$file = FileDao::getFileFromId($fid);
		}
		catch (Exception $e)
		{
			if(APP_DEBUG_LEVEL)
			throw new FrameworkImportedException($e);
		}

		if(!$confirm)
		{
			$dialogTitle = __('delete_file_dialog_title');
			$dialogMessage = __('delete_file_dialog_message',$file->getName());

			$cancelManialink = $this->request->createLink(null, 'index');
			$this->request->set('confirm', rand());
			$continueManialink = $this->request->createLink(null, null);
			$this->request->delete('confirm');

			$this->response->dialogTitle = $dialogTitle;
			$this->response->dialogMessage = $dialogMessage;
			$this->response->dialogButtonLabel = __('continue');
			$this->response->dialogButtonManialink = $continueManialink;
			$this->response->dialogButton2Label = __('cancel');
			$this->response->dialogButton2Manialink = $cancelManialink;
			$this->response->registerDialog('dialogs','generic_two_buttons_dialog');
			$this->chainActionAndView('user','index');
		}
		elseif($file->getUserId() == $this->data->user->getId())
		{
			$filename = APP_DOWNLOAD_PATH.$this->data->user->getLogin().'/'.$file->getName();
			if(file_exists($filename))
			unlink($filename);
			FileDao::delFileFileId($fid);
			UserDao::updateUserSpace($this->data->user->getId(),$file->getSize(),'remove');
			$this->request->delete('fid');
			$this->request->delete('confirm');
			$this->session->delete('user');
			$this->request->redirectManialinkArgList('user','index');
		}
	}

	function logout()
	{
		$this->session->delete('user');
		$this->session->delete('transaction');
		$this->request->redirectManialinkArgList('home','index');
	}
}
?>