<?php
/**
 * 
 * @author Philippe Melot
 * @copyright Nadeo
 */

class FileDao
{
	/**
	 * 
	 * @param string $filename
	 * @param string $owner
	 * @return File
	 */
	static function getFileFromName($filename, $owner)
	{
		if(!$filename)
			throw new InvalidArgumentException('$filename cannot be null');
		if(!$owner)
			throw new InvalidArgumentException('$owner cannot be null');
			
		$dbInstance = DatabaseFactory::getConnection();
		
		$filenameQuoted = $dbInstance->quote($filename);
		$ownerQuoted = $dbInstance->quote($owner);
		
		$query = "SELECT F.* FROM `".APP_DATABASE_PREFIX."File` F\n"
				."INNER JOIN `".APP_DATABASE_PREFIX."User` U ON U.id = F.userId\n"
				."WHERE F.`name` = $filenameQuoted AND U.`login` = $ownerQuoted";
							
		$resultSet = $dbInstance->execute($query);
		
		$file = null;
		if($resultSet->recordCount())
		{
			$result = $resultSet->fetchAssoc();
			if($result)
			{
				$file = new File();
				$file->setId($result['id']);
				$file->setName($result['name']);
				$file->setUserId($result['userId']);
				$file->setSize($result['size']);
				$file->setUploadTimestamp($result['uploadTimestamp']);
				$file->setDownloadNb($result['downloadNb']);
			}
			
		}
		return $file;
	}
	
	/**
	 * 
	 * @param int $fileId
	 * @return File
	 */
	static function getFileFromId($fileId)
	{
		if(!is_numeric($fileId))
			throw new InvalidArgumentException('$fileId must of integer type');
		
		$dbInstance = DatabaseFactory::getConnection();
		
		$query = "SELECT * FROM `".APP_DATABASE_PREFIX."File`\n"
				."WHERE `id` = $fileId";
							
		$resultSet = $dbInstance->execute($query);
		
		$file = null;
		if($resultSet->recordCount())
		{
			$result = $resultSet->fetchAssoc();
			if($result)
			{
				$file = new File();
				$file->setId($result['id']);
				$file->setName($result['name']);
				$file->setUserId($result['userId']);
				$file->setSize($result['size']);
				$file->setUploadTimestamp($result['uploadTimestamp']);
				$file->setDownloadNb($result['downloadNb']);
			}
			
		}
		return $file;
	}
	
	/**
	 * 
	 * @param int $owner
	 * @param int $offset
	 * @param int $length
	 * @return ArrayObject
	 */
	static function getFiles($userId, $offset = null, $length = null)
	{
		if(!is_numeric($userId))
			throw new InvalidArgumentException('$userId = '.$userId);
			
		$dbInstance = DatabaseFactory::getConnection();
		
		$query = "SELECT * FROM `".APP_DATABASE_PREFIX."File`\n"
				."WHERE `userId` = $userId\n"
				."ORDER BY `name` ASC\n";
		$query .= DatabaseTools::getLimitString($offset,$length);
		$resultSet = $dbInstance->execute($query);
		
		$retour = array();
		if($resultSet->recordCount())
		{
			while($result = $resultSet->fetchAssoc())
			{
				if($result)
				{
					$file = new File();
					$file->setId($result['id']);
					$file->setName($result['name']);
					$file->setUserId($result['userId']);
					$file->setSize($result['size']);
					$file->setUploadTimestamp($result['uploadTimestamp']);
					$file->setDownloadNb($result['downloadNb']);
					$retour[] = $file;
				}
			}
			
		}
		return $retour;
	}
	
	/**
	 * 
	 * @param int $userId
	 * @return int
	 */
	static function getFileCountFromUser($userId)
	{
		if(!is_numeric($userId))
			throw new InvalidArgumentException('$userId = '.$userId);
			
		$dbInstance = DatabaseFactory::getConnection();
		
		$query = "SELECT count(*) FROM `".APP_DATABASE_PREFIX."File`\n"
				."WHERE `userId` = $userId";
							
		$resultSet = $dbInstance->execute($query);
		
		return $resultSet->recordCount();
	}
	
	/**
	 * 
	 * @param string $name
	 * @param int $userId
	 * @param int $size
	 * @return int
	 */
	static function setFile($name, $userId, $size)
	{
		if(!$name)
			throw new InvalidArgumentException('$name cannot be null');
		if(!is_numeric($userId))
			throw new InvalidArgumentException('$userId must of integer type');
		if(!is_numeric($size))
			throw new InvalidArgumentException('$size must of integer type');
			
		$dbInstance = DatabaseFactory::getConnection();
		
		$nameQuoted = $dbInstance->quote($name);
		
		$query = "INSERT INTO `".APP_DATABASE_PREFIX."File` (`name`, `userId`, `size`, `uploadTimestamp`) VALUES\n"
				."($nameQuoted, $userId, $size, UNIX_TIMESTAMP())\n"
				."ON DUPLICATE KEY UPDATE `size` = $size, `uploadTimestamp` = UNIX_TIMESTAMP()";
							
		$resultSet = $dbInstance->execute($query);
		
		return $dbInstance->insertID();
	}
	
	/**
	 * 
	 * @param int $fileId
	 * @return int
	 */
	static function delFileFileId($fileId)
	{
		if(!is_numeric($fileId))
			throw new InvalidArgumentException('fileId');
			
		$dbInstance = DatabaseFactory::getConnection();
		
		$query = "DELETE FROM `".APP_DATABASE_PREFIX."File` WHERE `id` = $fileId";
		$dbInstance->execute($query);
		
		return $dbInstance->affectedRows();
	}
	
	/**
	 * 
	 * @param string $name
	 * @param int $userId
	 * @return int
	 */
	static function delFileFromName($name, $userId)
	{
		if(!$name)
			throw new InvalidArgumentException('name');
		if(!is_numeric($userId))
			throw new InvalidArgumentException('userId');
			
		$dbInstance = DatabaseFactory::getConnection();
		$name = $dbInstance->quote($name);
		
		$query = "DELETE FROM `".APP_DATABASE_PREFIX."File` WHERE `name` = $name AND `userId` = $userId";
		$dbInstance->execute($query);
		
		return $dbInstance->affectedRows();
	}
}
?>