<?php
/**
 * 
 * @author Philippe Melot
 * @copyright Nadeo
 */

class UserDao
{
	/**
	 *
	 * @param string $login
	 * @param int $transactionId
	 * @param int $isAdmin
	 * @return int
	 */
	static function setUser($login, $transactionId, $isAdmin = false)
	{
		if(!$login || strlen($login) > 25)
		throw new InvalidArgumentException('$login = '.$login);
		if(!is_bool($isAdmin))
		throw new InvalidArgumentException('$isAdmin = '.$isAdmin);
		if(!is_numeric($transactionId) || $transactionId < 0)
		throw new InvalidArgumentException('$transactionId = '.$transactionId);

		$dbInstance = DatabaseFactory::getConnection();

		$quotedLogin = $dbInstance->quote($login);

		$query = "INSERT INTO `".APP_DATABASE_PREFIX."User` (`login`, `isAdmin`, `subscriptionTime`, `expirationTime`, `transactionId`)\n"
		."VALUES ($quotedLogin, ".($isAdmin ? 1:0).", UNIX_TIMESTAMP() , UNIX_TIMESTAMP()+".DEFAULT_PERIOD.", $transactionId)";
			
		$resultSet = $dbInstance->execute($query);

		return $dbInstance->insertId();
	}

	/**
	 *
	 * @param int $userId
	 * @param int $transactionId
	 * @return int
	 */
	static function updateTransaction($userId, $transactionId)
	{
		if(!is_numeric($userId) || $userId <= 0)
		throw new InvalidArgumentException('$userId = '.$userId.' must be an integer');
		if(!is_numeric($transactionId) || $transactionId < 0)
		throw new InvalidArgumentException('$transactionId = '.$transactionId.' must be an integer');

		$dbInstance = DatabaseFactory::getConnection();

		$query = "UPDATE `".APP_DATABASE_PREFIX."User` SET `transactionId` = $transactionId,\n"
		.'`expirationTime` = IF(`expirationTime` < UNIX_TIMESTAMP(), UNIX_TIMESTAMP(), `expirationTime`)+'.DEFAULT_PERIOD."\n"
		."WHERE `id` = $userId";
			
		$resultSet = $dbInstance->execute($query);

		return $dbInstance->affectedRows();
	}

	/**
	 *
	 * @param int $userId
	 * @param int $trafficSize
	 * @return int
	 */
	static function updateTraffic($userId, $trafficSize)
	{
		if(!is_numeric($userId) && $userId <= 0)
		throw new InvalidArgumentException('userId');
		if(!is_numeric($trafficSize) && $trafficSize <= 0)
		throw new InvalidArgumentException('trafficSize');
			
		$query = "UPDATE `".APP_DATABASE_PREFIX."User` SET `trafficConsumption` = `trafficConsumption` + $trafficSize\n"
		."WHERE `id` = $userId";
		$dbInstance = DatabaseFactory::getConnection();
		$dbInstance->execute($query);

		return $dbInstance->affectedRows();
	}

	/**
	 *
	 * @param int $userId
	 * @param int $fileSize
	 * @param string $action
	 * @return int
	 */
	static function updateUserSpace($userId, $fileSize, $action = 'add')
	{
		if(!is_numeric($userId) && $userId <= 0)
		throw new InvalidArgumentException('userId');
		if(!is_numeric($fileSize) && $fileSize <= 0)
		throw new InvalidArgumentException('fileSize');
		if($action != 'add' && $action != 'remove')
		throw new InvalidArgumentException('action');
			
		if($action == 'remove')
		$fileSize *= -1;

		$query = "UPDATE `".APP_DATABASE_PREFIX."User` SET `occupiedSpace` = `occupiedSpace` + $fileSize\n"
		."WHERE `id` = $userId";
		$dbInstance = DatabaseFactory::getConnection();
		$dbInstance->execute($query);

		return $dbInstance->affectedRows();
	}

	/**
	 *
	 * @param string $login
	 * @return User
	 */
	static function getUserFromLogin($login)
	{
		if(!$login || strlen($login) > 25)
		throw new InvalidArgumentException('$login = '.$login.' is not a valid argument');

		$dbInstance = DatabaseFactory::getConnection();

		$quotedLogin = $dbInstance->quote($login);

		$query = "SELECT * FROM `".APP_DATABASE_PREFIX."User` WHERE `login` = $quotedLogin";
			
		$resultSet = $dbInstance->execute($query);

		if(!$resultSet->recordCount())
		return null;

		$user = $resultSet->fetchObject('User');

		return $user;
	}
	
	/**
	 * 
	 * @param int $userId
	 * @return User
	 */
	static function getUserFromId($userId)
	{
		if(!is_numeric($userId))
		throw new InvalidArgumentException('$userId = '.$userId.' is not a valid argument');

		$dbInstance = DatabaseFactory::getConnection();

		$query = "SELECT * FROM `".APP_DATABASE_PREFIX."User` WHERE `id` = $userId";
			
		$resultSet = $dbInstance->execute($query);

		if(!$resultSet->recordCount())
		return null;

		$user = $resultSet->fetchObject('User');

		return $user;
	}

	/**
	 *
	 * @param array $excludeUsers
	 * @return array
	 */
	static function getUserExpiredAccount($excludeUsers = array())
	{
		$dbInstance = DatabaseFactory::getConnection();

		$query = "SELECT * FROM `".APP_DATABASE_PREFIX."User` WHERE (`expirationTime` + 15 * 86400) < UNIX_TIMESTAMP()\n";
		if(count($excludeUsers))
		{
			foreach($excludeUsers as $key => $user)
			{
				$excludeUsers[$key] = $dbInstance->quote($user);
			}
			$excludeUsers = implode(',',$excludeUsers);
				
			$query .= "AND `login` NOT IN ($excludeUsers)";
		}

		$resultSet = $dbInstance->execute($query);

		$expiredAccount = array();

		if($resultSet->recordCount())
		{
			while($user = $resultSet->fetchObject('User'))
			$expiredAccount[] = $user;
		}

		return $expiredAccount;
	}

	/**
	 * @return int
	 */
	static function getUsersCount()
	{
		$dbInstance = DatabaseFactory::getConnection();

		$query = "SELECT count(*) FROM `".APP_DATABASE_PREFIX."User`";

		$resultSet = $dbInstance->execute($query);

		$result = $resultSet->fetchRow();

		return $result[0];
	}

	/**
	 *
	 * @param int $userId
	 * @return int
	 */
	static function rmUser($userId)
	{
		if(!is_numeric($userId))
		throw new InvalidArgumentException('$login = '.$login.' is not a valid argument');

		$dbInstance = DatabaseFactory::getConnection();

		$query = "DELETE FROM `".APP_DATABASE_PREFIX."User` WHERE `id` = $userId";
			
		$resultSet = $dbInstance->execute($query);

		return $dbInstance->affectedRows();
	}

	static function rmUsers($userIds = array())
	{
		if(count($userIds))
		{
			$userIds = implode(',',$userIds);

			$dbInstance = DatabaseFactory::getConnection();

			$query = "DELETE FROM `".APP_DATABASE_PREFIX."User` WHERE `id` IN ($userIds)";
				
			$resultSet = $dbInstance->execute($query);

			return $dbInstance->affectedRows();
		}
		else
		return 0;
	}
}
