<?php
/**
 *
 * @author Philippe Melot
 * @copyright Nadeo
 */

class PlayerDataRetrievalFilter extends AdvancedFilter
{
	/**
	 * @var DataEngine
	 */
	protected $data;

	function preFilter()
	{
		$this->data = DataEngine::getInstance();
		//		Check if the player is registered and if he has payed
		$user = unserialize($this->session->get('user'));
		$transaction = unserialize($this->session->get('transaction'));
		if(!$user)
		{
			$user = null;
			try
			{
				$user = UserDao::getUserFromLogin($this->session->getStrict('login'));
			}
			catch(Exception $e)
			{
				if(APP_DEBUG_LEVEL)
				{
					throw new FrameworkImportedException($e);
				}
				else
				{
					$this->request->redirectManialinkArgList('home','index');
				}
			}

			if($user == null || (!$this->response->isVip && $user->getExpirationTime() + 15 * 86400 < time()))
			{
				$this->request->redirectManialinkArgList('register','index');
			}
			$this->session->set('user',serialize($user));
		}
		if(!$transaction)
		{
			try
			{
				$transaction = TransactionDao::getTransaction($user->getTransactionId());
			}
			catch (Exception $e)
			{
				if(APP_DEBUG_LEVEL)
				{
					throw new FrameworkImportedException($e);
				}
				else
				{
					$this->request->redirectManialinkArgList('home','index');
				}
			}

			if(!$this->response->isVip)
			{
				if(!$transaction || $transaction->getStatus() == TransactionModel::INACTIVE || time() > $transaction->getCreationTime() + $transaction->getPeriod() * $transaction->getPaymentCount())
				{
					$this->request->redirectManialinkArgList('register','index');
				}
			}
			$this->session->set('transaction',serialize($transaction));
		}
		$this->data->user = $user;
		$this->data->transaction = $transaction;
	}

	function postFilter() {}
}

?>