<?php
/**
 * Handles creation and retrieval of graphes files
 */

require_once( FOLDER_TO_CONFIG.'graphes.php' );
//require_once( FOLDER_TO_LIBS_GRAPHES.'GraphData.class.php' );
 
abstract class CGraphManager
{
	const DISPLAY_URL = URL_GRAPHES_DISPLAY;
	
	const IMAGE_EXT = 'png';
	
	const BAR_PLOT = 1;
	const PIE = 2;
	
	const DEFAULT_TIME_TO_LIVE = 86400;
	
	static function CreateGraph(CGraphData $GraphData, $Type = CGraphManager::BAR_PLOT)
	{
		switch($Type)
		{
			case CGraphManager::BAR_PLOT:
				require_once( FOLDER_TO_LIBS_GRAPHES.'MultiBarPlot.class.php' );
				$RenderedData = MultiBarPlot::Render($GraphData);
				break;
			
			default:
				throw new GraphException('Unsupported graph type');
			
		}
		$Filename = self::GetCacheFilename($GraphData->Identifier);
		file_put_contents($Filename, $RenderedData);
	}
	
	static function CacheExpired($Identifier, $TimeToLive = self::DEFAULT_TIME_TO_LIVE)
	{
		$Filename = self::GetCacheFilename($Identifier);
		if(file_exists($Filename))
		{
			clearstatcache();
			if(time() - filemtime($Filename) < $TimeToLive)
			{
				return false;
			}
		}
		return true;
	}
	
	static function GetGraphURL($Identifier)
	{
		return self::DISPLAY_URL.'/'.$Identifier.'.'.self::IMAGE_EXT;
	}
	
	static protected function GetCacheFilename($Identifier)
	{
		return APP_PATH.'/images/graphes/'.$Identifier.'.'.self::IMAGE_EXT;
	}
}

class GraphException extends FrameworkException {}

final class CGraphData 
{
	public $Identifier;
	public $Title;
	public $XLabels = array();
	public $ValuesList = array();
	
	function __construct($Identifier=null, $Title=null)
	{
		$this->Identifier = $Identifier;
		$this->Title = $Title;
	}
	
	function ImportData(CGraphData $Data)
	{
		$this->ValuesList = $Data->ValuesList;
		$this->XLabels = $Data->XLabels;		
	}
}
?>