<?php
/**
 * Multi bar plot with Artichow
 */

require_once( FOLDER_TO_ARTICHOW.'BarPlot.class.php' );

/**
 * Renders and returns the PNG binary data of the graph
 */
abstract class MultiBarPlot
{
	static function Render(CGraphData $Data)
	{
		$black = new awColor(5, 5, 5);
		$white = new awColor(255, 255, 255);
		$grey = new awColor(100, 100, 100);
		$grey2 = new awColor(60, 60, 60);
		$yellow = new awColor(255, 255, 0);
		$orange = new awColor(255, 153, 0);
		$blackGradient = new awLinearGradient($grey2, $black, 0);
		$yellowGradient = new awLinearGradient($orange, $yellow, 0);
		
		$Graph = new awGraph(1000, 750);
		$Group = new awPlotGroup();
		
		$Graph->setBackgroundGradient($blackGradient);
		$Graph->title->setAlign(awLegend::CENTER, awLegend::TOP);
		$Graph->title->move(0, 70);
		$Graph->title->setPadding(1000, 1000, 25, 25);
		$Graph->title->setFont(new awTTFFont('TuffyBoldItalic', 30), $white);
		$Graph->title->setBackgroundColor($black);
		$Graph->title->border->setColor($grey);
		
		$Group->grid->setNoBackground();
		$Group->grid->hideVertical();
		$Group->grid->setColor($grey);
		
		$Group->axis->top->setColor($grey);
		$Group->axis->bottom->setColor($grey);
		$Group->axis->left->setColor($grey);
		$Group->axis->right->setColor($grey);
		
		$Group->axis->bottom->label->setFont(new awTTFFont('TuffyBold', 10));
		$Group->axis->bottom->label->setColor($white);
		
		$Group->axis->left->label->setFont(new awTTFFont('TuffyBold', 10));
		$Group->axis->left->label->setColor($white);
		
		$Group->setPadding(75, 25, 125, 110);
		$Group->legend->setPosition(0.5, 0.97);
		$Group->legend->setAlign(awLegend::CENTER, awLegend::BOTTOM);
		$Group->legend->setModel(awLegend::MODEL_BOTTOM);
		$Group->legend->setPadding(50, 50, 15, 15);
		$Group->legend->setSpace(50);
		$Group->legend->setTextFont(new awTTFFont('TuffyBoldItalic', 12));
		$Group->legend->setTextColor($white);
		$Group->legend->border->setColor($grey);
		
		$Group->legend->shadow->hide();
		$Group->legend->setBackground(null);
		
		// Data
		$Graph->title->set($Data->Title);
		$Group->axis->bottom->setLabelText($Data->XLabels);
		
		$i=0;
		$ValuesListCount = count($Data->ValuesList);
		foreach($Data->ValuesList as $Legend => $Values) 
		{
		    $Plot = new awBarPlot($Values, $i+1, $ValuesListCount);
		    
		    $Plot->setBarSize(0.7/$ValuesListCount);
		    $Plot->setBarGradient(
		    	new awLinearGradient(
		    		new awColor(255, 153, 0),
		    		new awColor(255, 255, 0), 
		    		0));
		    
	    $Plot->barBorder->setColor($black);
//		    $Plot->barShadow->setSize(5);
//		    $Plot->barShadow->setPosition(ArtichowShadow::RIGHT_TOP);
//		    $Plot->barShadow->setColor(CGraphColors::BarShadowColor());
//		    $Plot->barShadow->smooth(TRUE);
		    
		    //$Plot->barBorder->hide();
		    
		   	$Plot->label->set($Values);
		    $Plot->label->setColor($white);
		    $Plot->label->setFont(new awTTFFont('TuffyBold', 10));
			$Plot->label->move(0, -10);
			
			$Group->add($Plot);
		    $Group->legend->add($Plot, $Legend, awLegend::BACKGROUND);
			
			$i++;
		}
		
		$Graph->add($Group);
		$Graph->setFormat(awImage::PNG);
		return $Graph->draw(awGraph::DRAW_RETURN);
	}
}

?>