<?php
/**
 * Periodic transaction API
 * 
 * @author Maxime Raoust
 * @package Manialib
 */
 
/**
 * Transaction class
 * @package transaction
 */
class PeriodicTransaction
{
	const SCRIPT_CREATE = 'http://%s:%s@scripts.trackmaniaforever.com/newtransaction_create.php';
	const SCRIPT_PAY = 'http://%s:%s@scripts.trackmaniaforever.com/newtransaction_pay.php';
	const SCRIPT_IS_PAID = 'http://%s:%s@scripts.trackmaniaforever.com/newtransaction_ispaid.php';
	const SCRIPT_STOP_PAYING = 'http://%s:%s@scripts.trackmaniaforever.com/newtransaction_stoppaying.php';
	
	const TAX = 0.05;
	
	const ERROR_INTERNAL =                       1;
	const ERROR_MYSQL_QUERY =                    2;
	const ERROR_UNKNOWN_TRANSACTION =            3;
	const ERROR_UNKNOWN_PLAYER =                 4;
	const ERROR_INVALID_PASSWORD =               5;
	const ERROR_INVALID_SOLOACCOUNTVALIDATION =  6;
	const ERROR_BAD_TRANSACTION_COST =           7;
	const ERROR_SAME_LOGIN =                     8;
	const ERROR_NOT_AUTHENTICATED =              9;
	const ERROR_PERMISSION_DENIED =             10;
	const ERROR_ALREADY_PAID =                  11;
	const ERROR_NOT_ENOUGH_COPPERS =            12;
	const ERROR_BAD_TRANSACTION_NAME =          13;
//	const ERROR_BAD_TRANSACTION_COST =          14;
	const ERROR_BAD_TRANSACTION_PAYER =         15;
	const ERROR_BAD_TRANSACTION_PAYEE =         16;
	
	protected $id;
	protected $creatorLogin;
	protected $creatorPassword;
	protected $creatorSecurityKey;
	protected $payerLogin;
	protected $payeeLogin;
	protected $name;
	protected $cost;
	protected $period;
	
	static function pay($transactionId)
	{
		$params = array('transaction' => $transactionId);
		$url = sprintf(self::SCRIPT_PAY.'?'.http_build_query($params), APP_SCRIPTS_USER, APP_SCRIPTS_PASSWORD);
		$response = file_get_contents($url);
		$response = explode(';', $response);
		self::checkForError($response[0]);
	}
	
	static function isPaid($transactionId)
	{
		$params = array('transaction' => $transactionId);
		$url = sprintf(self::SCRIPT_IS_PAID.'?'.http_build_query($params), APP_SCRIPTS_USER, APP_SCRIPTS_PASSWORD);
		$response = file_get_contents($url);
		$response = explode(';', $response);
		self::checkForError($response[0]);
		if($response[1] == 1)
			return true;
		elseif($response[1] == 0)
			return false;
		else
			throw new PeriodicTransactionException($response[1]);
	}
	
	static function stopPaying($transactionId)
	{
		$params = array('transaction' => $transactionId);
		$url = sprintf(self::SCRIPT_STOP_PAYING.'?'.http_build_query($params), APP_SCRIPTS_USER, APP_SCRIPTS_PASSWORD);
		$response = file_get_contents($url);
		$response = explode(';', $response);
		self::checkForError($response[0]);
	}
	
	static function create(PeriodicTransaction $transaction)
	{
		$transaction->checkParameter('creatorLogin');
		$transaction->checkParameter('creatorPassword');
		$transaction->checkParameter('creatorSecurityKey');
		$transaction->checkParameter('payerLogin');
		$transaction->checkParameter('payeeLogin');
		$transaction->checkParameter('cost');
		$transaction->checkParameter('name');
		$transaction->checkParameter('period');
		
		$params = array(
			'login' => $transaction->getCreatorLogin(),
			'pass' => $transaction->getCreatorPassword(),
			'key' => $transaction->getCreatorSecurityKey(),
			'from' => $transaction->getPayerLogin(),
			'to' => $transaction->getPayeeLogin(),
			'cost' => $transaction->getCost(),
			'name' => $transaction->getName(),
			'repeated' => 1,
			'period' => $transaction->getPeriod()		
		);
		
		$url = sprintf(self::SCRIPT_CREATE.'?'.http_build_query($params), APP_SCRIPTS_USER, APP_SCRIPTS_PASSWORD);
		$response = file_get_contents($url);
		$response = explode(';', $response);
		self::checkForError($response[0]);
		
		$transaction->setId($response[1]);
	}
	
	static protected function checkForError($code)
	{
		// TODO Faire un meilleur switch sur les code d'erreur de transaction
		switch($code)
		{
			case 0: return;
			default: throw new PeriodicTransactionException($code);
		}
	}
	
	function __construct($name)
	{
		$this->name = $name;
	}
	
	function setId($id)
	{
		$this->id = $id;	
	}
	
	function getId()
	{
		return $this->id;
	}
	
	function setCreatorLogin($creatorLogin)
	{
		$this->creatorLogin = $creatorLogin;
	}
	
	function getCreatorLogin()
	{
		return $this->creatorLogin;
	}
	
	function setCreatorPassword($creatorPassword)
	{
		$this->creatorPassword = $creatorPassword;
	}
	
	function getCreatorPassword()
	{
		return $this->creatorPassword;
	}
	
	function setCreatorSecurityKey($creatorSecurityKey)
	{
		$this->creatorSecurityKey = $creatorSecurityKey;
	}
	
	function getCreatorSecurityKey()
	{
		return $this->creatorSecurityKey;
	}
	
	function setPayerLogin($payerLogin)
	{
		$this->payerLogin = $payerLogin;
	}
	
	function getPayerLogin()
	{
		return $this->payerLogin;
	}
	
	function setPayeeLogin($payeeLogin)
	{
		$this->payeeLogin = $payeeLogin;
	}
	
	function getPayeeLogin()
	{
		return $this->payeeLogin;
	}
	
	function getName()
	{
		return $this->name;
	}
	
	function setCost($cost)
	{
		$this->cost = $cost;
	}
	
	function setNetCost($netCost)
	{
		$this->cost = floor( 1/(1 + self::TAX) * $netCost );
	}
	
	function getCost()
	{
		return $this->cost;
	}
	
	function getNetCost()
	{
		return ceil( (1 + self::TAX) * $this->cost );
	}
	
	function setPeriod($period)
	{
		$this->period = $period;
	}
	
	function getPeriod()
	{
		return $this->period;
	}
	
	function checkParameter($name)
	{
		if(!$this->$name)
		{
			throw new PeriodicTransactionInvalidParameterException($name);
		}
	}
}

class PeriodicTransactionException extends FrameworkException {}
class PeriodicTransactionInvalidParameterException extends PeriodicTransactionException {}
?>